@@ -451,7 +451,7 @@ bool menu_is_visible(struct menu *menu)
 
 const char *menu_get_prompt(struct menu *menu)
 {
-	char *m = 0;
+	const char *m = 0;
 	if (menu->prompt)
 		m = menu->prompt->text;
 	else if (menu->sym)
